@@ -69,10 +69,10 @@ G_GNUC_EXTENSION typedef unsigned long long guint64;
 #define G_GUINT64_FORMAT "llu"
 
 
-#define GLIB_SIZEOF_VOID_P 4
-#define GLIB_SIZEOF_LONG   4
-#define GLIB_SIZEOF_SIZE_T 4
-#define GLIB_SIZEOF_SSIZE_T 4
+#define GLIB_SIZEOF_VOID_P 8
+#define GLIB_SIZEOF_LONG   8
+#define GLIB_SIZEOF_SIZE_T 8
+#define GLIB_SIZEOF_SSIZE_T 8
 
 typedef signed long gssize;
 typedef unsigned long gsize;
@@ -95,22 +95,22 @@ typedef gint64 goffset;
 
 #define G_POLLFD_FORMAT "%d"
 
-#define GPOINTER_TO_INT(p)	((gint)  (gint) (p))
-#define GPOINTER_TO_UINT(p)	((guint) (guint) (p))
+#define GPOINTER_TO_INT(p)	((gint)  (glong) (p))
+#define GPOINTER_TO_UINT(p)	((guint) (gulong) (p))
 
-#define GINT_TO_POINTER(i)	((gpointer) (gint) (i))
-#define GUINT_TO_POINTER(u)	((gpointer) (guint) (u))
+#define GINT_TO_POINTER(i)	((gpointer) (glong) (i))
+#define GUINT_TO_POINTER(u)	((gpointer) (gulong) (u))
 
-typedef signed int gintptr;
-typedef unsigned int guintptr;
+typedef signed long gintptr;
+typedef unsigned long guintptr;
 
-#define G_GINTPTR_MODIFIER      ""
-#define G_GINTPTR_FORMAT        "i"
-#define G_GUINTPTR_FORMAT       "u"
+#define G_GINTPTR_MODIFIER      "l"
+#define G_GINTPTR_FORMAT        "li"
+#define G_GUINTPTR_FORMAT       "lu"
 
 #define GLIB_MAJOR_VERSION 2
-#define GLIB_MINOR_VERSION 68
-#define GLIB_MICRO_VERSION 4
+#define GLIB_MINOR_VERSION 70
+#define GLIB_MICRO_VERSION 2
 
 #define G_OS_UNIX
 
@@ -170,18 +170,18 @@ typedef unsigned int guintptr;
 #define GINT64_TO_BE(val)	((gint64) GUINT64_SWAP_LE_BE (val))
 #define GUINT64_TO_BE(val)	(GUINT64_SWAP_LE_BE (val))
 
-#define GLONG_TO_LE(val)	((glong) GINT32_TO_LE (val))
-#define GULONG_TO_LE(val)	((gulong) GUINT32_TO_LE (val))
-#define GLONG_TO_BE(val)	((glong) GINT32_TO_BE (val))
-#define GULONG_TO_BE(val)	((gulong) GUINT32_TO_BE (val))
+#define GLONG_TO_LE(val)	((glong) GINT64_TO_LE (val))
+#define GULONG_TO_LE(val)	((gulong) GUINT64_TO_LE (val))
+#define GLONG_TO_BE(val)	((glong) GINT64_TO_BE (val))
+#define GULONG_TO_BE(val)	((gulong) GUINT64_TO_BE (val))
 #define GINT_TO_LE(val)		((gint) GINT32_TO_LE (val))
 #define GUINT_TO_LE(val)	((guint) GUINT32_TO_LE (val))
 #define GINT_TO_BE(val)		((gint) GINT32_TO_BE (val))
 #define GUINT_TO_BE(val)	((guint) GUINT32_TO_BE (val))
-#define GSIZE_TO_LE(val)	((gsize) GUINT32_TO_LE (val))
-#define GSSIZE_TO_LE(val)	((gssize) GINT32_TO_LE (val))
-#define GSIZE_TO_BE(val)	((gsize) GUINT32_TO_BE (val))
-#define GSSIZE_TO_BE(val)	((gssize) GINT32_TO_BE (val))
+#define GSIZE_TO_LE(val)	((gsize) GUINT64_TO_LE (val))
+#define GSSIZE_TO_LE(val)	((gssize) GINT64_TO_LE (val))
+#define GSIZE_TO_BE(val)	((gsize) GUINT64_TO_BE (val))
+#define GSSIZE_TO_BE(val)	((gssize) GINT64_TO_BE (val))
 #define G_BYTE_ORDER G_LITTLE_ENDIAN
 
 #define GLIB_SYSDEF_POLLIN =1
